// src/index.ts
import { existsSync } from "fs";
import fse from "fs-extra";
import chokidar from "chokidar";
var cacheDir = "./node_modules/.vite";
var metadataPath = `${cacheDir}/deps/_metadata.json`;
function VitePluginDepsCache({ delay = 2e3, field = "vite-deps-cache" } = {}) {
  let includedCache;
  let pkgJson;
  let server;
  async function handleDeps() {
    if (!existsSync(metadataPath))
      return;
    const metadataJson = await fse.readJSON(metadataPath, "utf-8");
    pkgJson[field] = [...pkgJson[field], ...Object.keys(metadataJson.optimized).filter((dep) => !includedCache.includes(dep))];
    setTimeout(() => {
      if (server)
        server.watcher.unwatch("./package.json");
      fse.writeJSON("./package.json", pkgJson, { spaces: 2 });
      if (server)
        server.watcher.add("./package.json");
    }, delay);
  }
  return {
    name: "vite-plugin-deps-cache",
    apply: "serve",
    async config(config) {
      var _a, _b, _c;
      pkgJson = await fse.readJSON("./package.json", "utf-8");
      config.optimizeDeps = {
        ...config.optimizeDeps,
        include: [
          ...(_b = (_a = config.optimizeDeps) == null ? void 0 : _a.include) != null ? _b : [],
          ...(_c = pkgJson[field]) != null ? _c : pkgJson[field] = []
        ]
      };
    },
    configResolved(config) {
      var _a;
      includedCache = (_a = config.optimizeDeps.include) != null ? _a : [];
      const watcher = chokidar.watch(cacheDir, {
        cwd: config.root
      });
      const timer = setInterval(() => {
        if (existsSync(cacheDir)) {
          watcher.on("change", (path) => {
            if (path.endsWith("_metadata.json"))
              handleDeps();
          });
          clearInterval(timer);
          handleDeps();
        }
      }, 1e3);
    },
    configureServer(_server) {
      server = _server;
    }
  };
}
export {
  VitePluginDepsCache as default
};
